
# Slot: base


python base type that implements this type definition

URI: [linkml:base](https://w3id.org/linkml/base)


## Domain and Range

[TypeDefinition](TypeDefinition.md) &#8594;  <sub>0..1</sub> [String](String.md)

## Parents


## Children


## Used by

 * [TypeDefinition](TypeDefinition.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Comments:** | | every root type must have a base |
|  | | the base is inherited by child types but may be overriden.  Base compatibility is not checked. |

